@@ -26,8 +26,18 @@ use structopt::{clap::AppSettings::ColoredHelp, StructOpt};
 use termcolor::ColorChoice;
 
 lazy_static! {
-    /// Return the number of cpus as an &str
-    pub static ref NUM_CPU: String = num_cpus::get().to_string();
+    /// Default number of compression threads to use.
+    ///
+    /// This will be 4 if >= 4 threads are present, otherwise it will
+    /// be num_cpus - 1.
+    pub static ref DEFAULT_CPUS: String = {
+        let num_cores = num_cpus::get();
+        if num_cores < 4 {
+            num_cores.saturating_sub(1)
+        } else {
+            4
+        }.to_string()
+    };
 }
 
 pub mod built_info {
@@ -169,7 +179,7 @@ struct Opts {
     try_compress: bool,
 
     /// Threads to use for compression, 0 will result in `hck` staying single threaded.
-    #[structopt(short = "t", long, default_value=NUM_CPU.as_str())]
+    #[structopt(short = "t", long, default_value=DEFAULT_CPUS.as_str())]
     compression_threads: usize,
 
     /// Compression level
@@ -1395,4 +1405,40 @@ mod test {
             ]
         );
     }
+
+    #[rstest]
+    fn test_issue_38_not_regex(
+        #[values(true, false)] no_mmap: bool,
+        #[values("    ", " ")] hck_delim: &str,
+    ) {
+        let tmp = TempDir::new().unwrap();
+        let input_file = tmp.path().join("input.txt");
+        let output_file = tmp.path().join("output.txt");
+        // 4-5 should not be repeated at the end and only written once.
+        let opts = build_opts_not_regex(&input_file, &output_file, "1,2", no_mmap, hck_delim);
+        let data = vec![
+            vec![""],
+            vec![""],
+            vec!["a", "b", "c", "d", "e", "f", "g"],
+            vec![""],
+            vec![""],
+            vec!["1", "2", "3", "4", "5", "6", "7"],
+        ];
+        write_file(&input_file, data, hck_delim);
+        run_wrapper(&input_file, &output_file, &opts);
+        let filtered = read_tsv(output_file);
+
+        // columns past end in fields are ignored
+        assert_eq!(
+            filtered,
+            vec![
+                vec![""],
+                vec![""],
+                vec!["a", "b"],
+                vec![""],
+                vec![""],
+                vec!["1", "2"]
+            ]
+        );
+    }
 }
